***********************
Usage and configuration
***********************




Sometimes, running *PyMend* with its defaults and passing filepaths to it just won't cut
it. Passing each file using paths will become burdensome, and maybe you would like
*PyMend* to not touch your files and just output diffs. And yes, you *can* tweak certain
parts of *PyMends*'s style.

Using many of these more advanced features of *PyMend* will require some configuration.
Configuration that will either live on the command line or in a TOML configuration file.

This section covers features of *PyMend* and configuring *PyMend* in detail:

.. toctree::
    the_basics
